# Contributing to Glimpse Image Editor
Thank you for your interest in contributing to the Glimpse project! Feel free to reach out to us on the #glimpse:matrix.org Matrix channel and read the latest project news on https://glimpse-editor.org.

Before getting in contact, please familiarize yourself with our [code of conduct](https://glimpse-editor.org/code-of-conduct/). For convenience we have provided a copy of that document with the source code in a file called `CODE_OF_CONDUCT.md`.

## Contents <a name="top"></a>
* [Beginner questions](#beginner-questions)
* [Ask for help](#ask-for-help)
* [Report a bug](#report-a-bug)
* [Suggest a new feature](#suggest-a-new-feature)
* [Build and test the code](#build-and-test-the-code)
* [Contribute code changes](#contribute-code-changes)
* [Contribute documentation](#contribute-documentation)
* [Contribute translations](#contribute-translations)
* [Join the community](#join-the-community)
* [Donate funds](#donate-funds)
* [Follow project news](#follow-project-news)
* [More information](#more-information)

## Beginner questions
### "What license is this source code provided under?"
Glimpse Image Editor is licensed under the terms of the GNU General Public License version 3. You can read more details in `COPYING` and `LICENSE`.

### "Which free software project did you fork from?"
The GNU Image Manipulation Program. We believe the "Gimp" name, over-use of a cartoon dog throughout the user interface and an overly-complicated user experience are discouraging individuals and organizations from adopting that software. We want to resolve those problems.

### "Did you really need to fork the project?"
Unfortunately, yes. People had been asking for these changes for over a decade before we began, so now a group of enthusiasts from outside that project are doing their best to implement those ideas.

### "Can you not just use find and replace to change the name?"
No. Refactoring the code and changing variable names breaks the build scripts, sub-components and plug-ins that Glimpse Image Editor relies on. There are also situations where it makes more sense to preserve the original application name (eg. save file compatibility statements, descriptions for plug-ins/procedures, etc).

### "Why do you need monetary donations?"
We ask for monetary donations to reimburse costs such as server hosting, web domains, code signing certificates and professional artwork (among other things). A portion of the donations we receive are also passed back to the GNU Image Manipulation Program each time we produce a new release so that we continue to support the development of components our project relies on.

The Glimpse project is strictly not-for-profit, and you can scrutinize all of our finances here: https://opencollective.com/glimpse/

### "Do you want to become more popular than the GIMP?"
Our primary objective is to expand the use of free software and help new people join the free software community. Replacing the GNU Image Manipulation Program is not our goal, and we believe that supporting and collaborating with the project we forked from is a more productive route forward.

### "Are you planning a complete rewrite?"
Possibly. There has been some early talk about replacing the user interface and plug-in framework, while still using the same underlying components like [GEGL](http://www.gegl.org/). However that is not likely to happen for a number of years (if it ever happens at all), so we primarily focus on improving GNU Image Manipulation Program 2.10.

## Ask for help
There are a number of ways to request support:

* Raise an issue on our [Github project](https://github.com/glimpse-editor/Glimpse) using the "question" template
* Reach out to us on the #glimpse:matrix.org Matrix channel
* Send us a message on social media (we monitor accounts on [the fediverse](https://bobadon.co.uk/@glimpse), [Facebook](https://www.facebook.com/glimpse.editor) and [Twitter](https://twitter.com/glimpse_editor))

[Return to top](#top)

## Report a bug
There are a number of ways to report a bug:

* Raise an issue on our [Github project](https://github.com/glimpse-editor/Glimpse) using the "bug report" template
* Reach out to us on the #glimpse:matrix.org Matrix channel
* Send us a message on social media (we monitor accounts on [the fediverse](https://bobadon.co.uk/@glimpse), [Facebook](https://www.facebook.com/glimpse.editor) and [Twitter](https://twitter.com/glimpse_editor))

[Return to top](#top)

## Suggest a new feature
There are a number of ways to request a new feature:

* Raise an issue on our [Github project](https://github.com/glimpse-editor/Glimpse) using the "feature request" template
* Reach out to us on the #glimpse:matrix.org Matrix channel
* Send us a message on social media (we monitor accounts on [the fediverse](https://bobadon.co.uk/@glimpse), [Twitter](https://twitter.com/glimpse_editor) and [Facebook](https://www.facebook.com/glimpse.editor))

[Return to top](#top)

## Build and test the code
You can find full instructions for this specific release in the `HACKING` file provided with this source code.

Instructions for newer releases are available on the Glimpse development wiki: https://wiki.glimpse-editor.org.

[Return to top](#top)

## Contribute code changes
Raise a pull request on our [Github project](https://github.com/glimpse-editor/Glimpse) and follow the template.

[Return to top](#top)

## Contribute documentation
To change the code-level documentation, raise a pull request on our [Github project](https://github.com/glimpse-editor/Glimpse) and follow the template.

To make changes to the project website, raise a pull request against our website's [Github repository](https://github.com/glimpse-editor/getglimpse-web).

To add content to the Glimpse developer wiki, request an account on https://wiki.glimpse-editor.org.

If you have expertise to provide for our future end user online and offline help pages, please join us on the #glimpse:matrix.org Matrix channel.

[Return to top](#top)

## Contribute translations
To change translation files in the codebase, raise a pull request on our [Github project](https://github.com/glimpse-editor/Glimpse) and follow the template.

If you have expertise to provide for our future translation tools, please join us on the #glimpse:matrix.org Matrix channel.

[Return to top](#top)

## Join the community
We recommend you familiarize yourself with our [code of conduct](https://glimpse-editor.org/code-of-conduct/) and [how we govern ourselves](https://glimpse-editor.org/about/#how-does-this-project-govern-itself).

Once you have done so, you are welcome to join us on the #glimpse:matrix.org Matrix channel. That communication channel is where our internal discussions happen and project decisions are made.

As you become more involved with the project you will be invited onto other Matrix channels and credited in our `AUTHORS` file.

[Return to top](#top)

## Donate funds
If you would like to help us cover the costs of running the Glimpse project, you can do so here: https://opencollective.com/glimpse/

You can also scrutinize how much we receive in donations and what we spend that money on. We are a strictly not-for-profit project, and we periodically pass on a portion of our donations to the GNU Image Manipulation Program.

[Return to top](#top)

## Follow project news
We provide regular blog post updates on our project website and its "full text" RSS feed: https://glimpse-editor.org.

You can also follow us on social media platforms such as [the fediverse](https://bobadon.co.uk/@glimpse), [Facebook](https://www.facebook.com/glimpse.editor) and [Twitter](https://twitter.com/glimpse_editor).

[Return to top](#top)

## More information
You can find out more about the Glimpse project on our website: https://glimpse-editor.org/about/

Our future development roadmap is also available here: https://github.com/glimpse-editor/Glimpse/milestones

[Return to top](#top)
